==> projectx-sdk-1.1.05-20220117.101652-3-sources.jar: cn/com/duiba/projectx/sdk/component/task/dto/TaskItemResult.java <==
package cn.com.duiba.projectx.sdk.component.task.dto;

import cn.com.duiba.projectx.sdk.component.base.OptionResult;
import cn.com.duiba.projectx.sdk.component.base.PendingResult;

import java.util.List;

public class TaskItemResult extends OptionResult {

    /**
     * 玩法ID
     */
    private String playwayId;

    /**
     * 任务ID
     */
    private String id;

    /**
     * 任务标识
     */
    private String code;

    /**
     * 任务标题
     */
    private String title;

    /**
     * 任务副标题
     */
    private String subTitle;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务图标
     */
    private String icon;

    /**
     * 按钮文案
     */
    private String buttonText;

    /**
     * 任务跳转URL
     */
    private String jumpUrl;

    /**
     * 任务限制类型
     * 0=不限制
     * 1=日
     * 2=周
     * 3=月
     * 4=永久
     */
    private Integer intervalType;

    /**
     * 任务限制次数
     */
    private Integer intervalLimitSize;

    /**
     * 已完成的次数
     */
    private Integer completedSize;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 当前这一次是否发奖
     */
    private Boolean sendPrize;

    /**
     * 领奖Code
     */
    private String prizePendingCode;

    private List<PendingResult> prizePendingCodeList;

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public Integer getIntervalType() {
        return intervalType;
    }

    public void setIntervalType(Integer intervalType) {
        this.intervalType = intervalType;
    }

    public Integer getIntervalLimitSize() {
        return intervalLimitSize;
    }

    public void setIntervalLimitSize(Integer intervalLimitSize) {
        this.intervalLimitSize = intervalLimitSize;
    }

    public Integer getCompletedSize() {
        return completedSize;
    }

    public void setCompletedSize(Integer completedSize) {
        this.completedSize = completedSize;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Boolean getSendPrize() {
        return sendPrize;
    }

    public void setSendPrize(Boolean sendPrize) {
        this.sendPrize = sendPrize;
    }

    public String getPrizePendingCode() {
        return prizePendingCode;
    }

    public void setPrizePendingCode(String prizePendingCode) {
        this.prizePendingCode = prizePendingCode;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<PendingResult> getPrizePendingCodeList() {
        return prizePendingCodeList;
    }

    public void setPrizePendingCodeList(List<PendingResult> prizePendingCodeList) {
        this.prizePendingCodeList = prizePendingCodeList;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }
}

==> projectx-sdk-1.1.55-sources.jar: cn/com/duiba/projectx/sdk/component/task/dto/TaskItemResult.java <==
package cn.com.duiba.projectx.sdk.component.task.dto;

import cn.com.duiba.projectx.sdk.component.base.OptionResult;
import cn.com.duiba.projectx.sdk.component.base.PendingResult;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import java.util.Objects;

public class TaskItemResult extends OptionResult {

    /**
     * 玩法ID
     */
    private String playwayId;

    /**
     * 任务ID
     */
    private String id;

    /**
     * 任务标识
     */
    private String code;

    /**
     * 任务标题
     */
    private String title;

    /**
     * 任务副标题
     */
    private String subTitle;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务图标
     */
    private String icon;

    /**
     * 按钮文案
     */
    private String buttonText;

    /**
     * 任务跳转URL
     */
    private String jumpUrl;

    /**
     * 任务限制类型
     * 0=不限制
     * 1=日
     * 2=周
     * 3=月
     * 4=永久
     */
    private Integer intervalType;

    /**
     * 任务限制次数
     */
    private Integer intervalLimitSize;

    /**
     * 已完成的次数
     */
    private Integer completedSize;

    /**
     * 任务状态
     * 0 去完成，任务完成次数未达到上限
     * 1 待领奖
     * 2 已完成，任务完成次数达到上限
     *
     */
    private Integer taskStatus;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 当前这一次是否发奖
     */
    private Boolean sendPrize;

    /**
     * 领奖Code
     */
    private String prizePendingCode;

    public Integer getTaskStatus() {
        if(StringUtils.isNoneBlank(prizePendingCode)){
            return 1;
        }
        if(intervalType==0||intervalLimitSize==null){
            return 0;
        }
        if(completedSize==null){
            return 0;
        }
        if(completedSize<intervalLimitSize){
            return 0;
        }
        return 2;
    }

    private List<PendingResult> prizePendingCodeList;

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public Integer getIntervalType() {
        return intervalType;
    }

    public void setIntervalType(Integer intervalType) {
        this.intervalType = intervalType;
    }

    public Integer getIntervalLimitSize() {
        return intervalLimitSize;
    }

    public void setIntervalLimitSize(Integer intervalLimitSize) {
        this.intervalLimitSize = intervalLimitSize;
    }

    public Integer getCompletedSize() {
        return completedSize;
    }

    public void setCompletedSize(Integer completedSize) {
        this.completedSize = completedSize;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Boolean getSendPrize() {
        return sendPrize;
    }

    public void setSendPrize(Boolean sendPrize) {
        this.sendPrize = sendPrize;
    }

    public String getPrizePendingCode() {
        return prizePendingCode;
    }

    public void setPrizePendingCode(String prizePendingCode) {
        this.prizePendingCode = prizePendingCode;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<PendingResult> getPrizePendingCodeList() {
        return prizePendingCodeList;
    }

    public void setPrizePendingCodeList(List<PendingResult> prizePendingCodeList) {
        this.prizePendingCodeList = prizePendingCodeList;
    }

    public String getSubTitle() {
        return subTitle;
    }

    public void setSubTitle(String subTitle) {
        this.subTitle = subTitle;
    }
}
